## About

This is a module that contains some backported fixes from the node.js v0.5.x core libraries in order to enable node v0.4.x to have the same level of stability. This module will be maintained as long as any of the previous statements is true:

 * node.js v0.5.x is unstable **or** node.js v0.4.x still won't backport fixes to v0.4.10+ from v0.5.x.
 * migrating my applications to node.js v0.5.x may crash some 3rd party modules that still depend on v0.4.x (examples: [mysql-libmysqlclient](https://github.com/Sannis/node-mysql-libmysqlclient), [compressor](https://github.com/egorich239/node-compress)).
 * somebody requests reasonable support for this module. No features will be added. Just bugfixes. This is what you ought to understand from *reasonable support*. Nowever, if adopting newer version is trivial, the newer version will be used, with minimal modifications in order to make it fit into this module.

## Installation

Either manually clone this repository into your node_modules directory, or the recommended method:

> npm install backport-0.4

## Backported fixes

More fixes may be backported, but this module specifically targets these:

 * [#877](https://github.com/joyent/node/issues/877) - Agent never establishes connections simultaneously
 * [#1085](https://github.com/joyent/node/issues/1085) - AssertionError if the request is aborted into the data event while the response emits a single data event.
 * [#1304](https://github.com/joyent/node/issues/1304) - Aborting a HTTPS request crashes the tls module.

## Available modules

 * http
 * https
 * tls

The modules are the modules from node.js v0.5.1. The http module doesn't have the DTrace support that the core http module has. The reason is to keep the backporting effort to minim since node doesn't expose the used DTrace functions as globals.

## Usage mode

The backport-0.4 module contains a simple loader for the provided backported core modules. Basically it resumes to this:

```javascript
// load the backported http module
var http = require('backport-0.4').load('http');

// load the backported https module
var https = require('backport-0.4').load('https');

// load the backported tls module
var tls = require('backport-0.4').load('tls');
```

The rest of the invocation follows the logic of the core module itself. This module specifically targets node v0.4.9.
